@@ -14,6 +14,7 @@ use Dancer::Plugin::Controller '0.15';
 use TestApp::Action::Test;
 use TestApp::Action::Test_404;
 use TestApp::Action::Test_Inherit;
+use TestApp::Action::TestCustomMethod;
 
 get '/' => sub { 
 	my $res = controller(action => 'Test');
@@ -41,4 +42,11 @@ get '/inherit' => sub {
 	}
 };
 
+get '/custom_action_method' => sub { 
+	my $res = controller(action => 'TestCustomMethod');
+	if (ref $res) {
+		return $res->{result};
+	}
+};
+
 1;
